@@ -31,7 +31,7 @@
  */
 class DolphinDirLister : public KDirLister
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
