@@ -51,7 +51,7 @@ class PixmapViewer;
  */
 class IconsViewSettingsPage : public TQVBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
