@@ -36,8 +36,8 @@ StatusBarMessageLabel::StatusBarMessageLabel(TQWidget* parent) :
     setMinimumHeight(TDEIcon::SizeSmall);
 
     m_timer = new TQTimer(this);
-    connect(m_timer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(timerDone()));
+    connect(m_timer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(timerDone()));
 }
 
 StatusBarMessageLabel::~StatusBarMessageLabel()
@@ -138,7 +138,7 @@ void StatusBarMessageLabel::paintEvent(TQPaintEvent* /* event */)
 void StatusBarMessageLabel::resizeEvent(TQResizeEvent* event)
 {
     TQWidget::resizeEvent(event);
-    TQTimer::singleShot(0, this, TQT_SLOT(assureVisibleText()));
+    TQTimer::singleShot(0, this, TQ_SLOT(assureVisibleText()));
 }
 
 void StatusBarMessageLabel::timerDone()
